%==========================================================================
% [init_dp_claw.m] Initialize CLAW for specified mode
%
%   Author: T.S.C. Pollack
%   Copyright (2024) T.S.C. Pollack
%==========================================================================
    
 % EMF-INDI
if strfind(options.claw.mode,'mf')

    % Set feedforward gain for completeness
    K_ff   = tf(1);    
    
    % Define virtual control feedback gains
    Kp = tunableGain('Kp',2*D*w0); Kp.Gain.Minimum = 0; Kp = genss(Kp);
    
    if strfind(options.claw.mode,'comp')
        Ki = tunableGain('Ki',1/2*w0/D);   Ki.Gain.Minimum = 0; Ki = genss(Ki);
    else
        Ki = tunableGain('Ki',w0^2);   Ki.Gain.Minimum = 0; Ki = genss(Ki);
    end

    % First-order virtual control lead-lag compensator
    C_vc_1   = tunableTF('C_vc',1,1);
    C_vc_1.Numerator.Value = 2*D*w0*[1 5];
    C_vc_1.Denominator.Value = [1 5]; 
    C_vc_1.Numerator.Minimum(1) = 0;
    C_vc_1.Numerator.Minimum(end) = 0;
    C_vc_1.Denominator.Minimum(1) = 0;
    C_vc_1.Denominator.Minimum(end) = 0;
    C_vc_1.Denominator.Maximum(end) = 100;
    C_vc_1   = genss(C_vc_1);

    % Second-order virtual control lead-lag compensator
    C_vc   = tunableTF('C_vc',2,2); 
    C_vc.Numerator.Value = 2*D*w0*[1 140 100^2];
    C_vc.Denominator.Value = [1 140 100^2]; 
    C_vc.Denominator.Maximum(2) = 200;
    C_vc.Denominator.Maximum(end) = 100^2;
    C_vc   = genss(C_vc);
    
    % Inversion (compensation) parameters
    wn_f   = tunableGain('wn_f',20); 
    wn_f.Gain.Minimum = 1; wn_f.Gain.Maximum = 100; wn_f = genss(wn_f);
    
    zeta_f = tunableGain('zeta_f',sqrt(1/2));
    zeta_f.Gain.Free = 0; zeta_f = genss(zeta_f);
    
    Kc     = tunableGain('Kc',1);  
    Kc.Gain.Minimum = 0; Kc.Gain.Maximum = 1;  Kc = genss(Kc);
    
    % Is specified, initialize DPs from external file
    if ~isempty(f_claw_init)
        
        % Load
        K_CLAW_EXT = load(f_claw_init,'K_CLAW'); 
        K_CLAW_EXT = K_CLAW_EXT.K_CLAW;
        
        % Check if conversion is available
        if exist('K_vc_conv','var')
            K_CLAW_EXT = setBlockValue(K_CLAW_EXT,K_vc_conv);
        end
        
        % Overwrite parameters
        Kp         = setBlockValue(Kp,K_CLAW_EXT);
        Ki         = setBlockValue(Ki,K_CLAW_EXT);
        C_vc_1     = setBlockValue(C_vc_1,K_CLAW_EXT);
        C_vc       = setBlockValue(C_vc,K_CLAW_EXT);
        wn_f       = setBlockValue(wn_f,K_CLAW_EXT);
        Kc         = setBlockValue(Kc,K_CLAW_EXT);
        
    end

end   