function K_vc_out = fcn_convert_Kvc(K_vc)
%   FCN_CONVERT_KVC Convert Kvc integrator and lead-lag elements
%
%       Author: T.S.C. Pollack
%       Copyright (2024) T.S.C. Pollack
    
    % Get compensator data
    C_vc_syn = getBlockValue(K_vc,'C_vc');
    [Z,P,~]  = zpkdata(C_vc_syn);
    
    % Get P & I gains
    Kp_syn   = dcgain(C_vc_syn);
    Ki_syn   = getBlockValue(K_vc,'Ki');
        
    % Convert
    tau_n  = Ki_syn.D;
    tau_d  = abs(P{1});
    Ki_out = abs(Z{1});   
    Kp_out = Kp_syn*Ki_syn/Ki_out;
    
    % Redefine compensator
    C_vc_syn_out = Kp_out*tau_d/tau_n*tf([1 tau_n],[1 tau_d]);
    
    % Generate output
    K_vc_out = setBlockValue(K_vc,'C_vc',C_vc_syn_out);    
    K_vc_out = setBlockValue(K_vc_out,'Ki',Ki_out);  

end